@@ -705,7 +705,7 @@ class ClassificationAnalysis(ModelAnalysis):
             X:
                 Feature matrix.
 
-             y:
+            y:
                 Target data vector.
 
             pred_name:
@@ -958,7 +958,7 @@ class ClassificationAnalysis(ModelAnalysis):
             X:
                 Feature matrix.
 
-            y:
+            y: list or np.array
                 Target data vector.
 
             pred_name:
@@ -1112,7 +1112,7 @@ class ClassificationAnalysis(ModelAnalysis):
             X: np.matrix or lists of lists
                 Feature matrix.
 
-            y: collection object
+            y: list or np.array
                 Target data vector.
 
             pred_name: str
@@ -1289,7 +1289,7 @@ class ClassificationAnalysis(ModelAnalysis):
             X: np.matrix or lists of lists
                 Feature matrix.
 
-            y: collection object
+            y: list or np.array
                 Target data vector.
 
             pred_name: str
@@ -1459,7 +1459,6 @@ class ClassificationAnalysis(ModelAnalysis):
                               display_visuals=True,
                               save_file=True):
         """
-
             Creates a report of all target's metric evaluations
             based on the model's prediction output from the classification report
             from the sklearn.
@@ -1468,7 +1467,7 @@ class ClassificationAnalysis(ModelAnalysis):
             X:
                 Feature matrix.
 
-             y:
+            y:
                 Target data vector.
 
             pred_name:
@@ -1529,6 +1528,20 @@ class ClassificationAnalysis(ModelAnalysis):
                                 feature_order,
                                 feature_importances,
                                 display_visuals=True):
+        """
+            Graph given models's feature importances
+
+        Args:
+            feature_order: list
+                Features names in proper order to re-create the pandas dataframe.
+
+            feature_importances: list
+                List of floats that represent each corresponding features importance
+
+            display_visuals: bool
+                Visualize graph if needed.
+        """
+
 
         feature_importances, feature_order = zip(
             *sorted(zip(feature_importances, feature_order), reverse=True))
@@ -1575,10 +1588,10 @@ class ClassificationAnalysis(ModelAnalysis):
             Finds the model's predicted labels.
 
         Args:
-            X:
+            X: np.matrix or np.array
                 Feature matrix.
 
-            pred_name:
+            pred_name: str
                 The name of the prediction function in questioned stored in 'self.__pred_funcs_dict'
 
             thresholds:
@@ -1642,7 +1655,7 @@ class ClassificationAnalysis(ModelAnalysis):
             X:
                 Feature matrix.
 
-            pred_name:
+            pred_name: str
                 The name of the prediction function in questioned stored in 'self.__pred_funcs_dict'
 
         Raises:
